.. bio-attention documentation master file, created by
   sphinx-quickstart on Tue Apr  4 13:08:09 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

bio-attention documentation
===================================

`GitHub page <https://github.com/gdewael/bio-attention>`_

.. include:: ../../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :caption: API Reference:

   Attention/Transformer modules <attention>
   Embedding modules <embed>
   Positional bias modules <positional>


..
   Indices and tables
   ==================

..
   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
